%% pmedf_removeInHeader --- remove line of the given key in edf file header
%%
%% Usage:
%%	header = pmedf_removeInHeader( header, key )
%%
%% In the 'header' (a string, usually a multiple of 512 B as the ESRF edf file
%% header), find keyword 'key' and remove the whole associated line. Keep the
%% original size of the header.
%%
%% Tech note: regular expression for a header line is
%%	\nkey [ ]*= [ ]*value[ ]*;\n
%% (correct edf header) or (broken edf header with "key=")
%%	\nkey=[ ]*value[ ]*;\n
%%
%% Example:
%%	header = pmedf_removeInHeader( header, 'row_end' );
%%
%% Author: Petr Mikulik
%% Version: 13. 1. 2017
%% History:
%%	19. 1. 2017:
%%		Allow parsing "key[ ]*=" as well as "key=".
%%		Use sprintf() instead of repmat().
%%		Replaced findstr() by strfind().
%%	12.10. 2008:
%%		Replace a==[] by isempty(a).
%%	 2. 5. 2002:
%%		Original version.

function header = pmedf_removeInHeader( header, key )

if nargin~=2
    error('syntax: pmedf_removeInHeader(...)');
end

key2 = sprintf(['\n' key ' ']);
value = strfind(header, key);
% Search for "\nkey " only:
% if isempty(value) return; end
% Search for "\nkey " or "\nkey=":
if isempty(value)
    key2 = sprintf(['\n' key '=']);
    value = strfind(header, key2);
    if isempty(value) return; end
end

orig_size = length(header);
header_beg = [header(1:value(1)-1) sprintf('\n')];
    % crazy sprintf('\n') instead of "\n" due to Matlab incompatibility
header = header(value(1):length(header));
p = strfind(header, sprintf(';\n'));
header = header(p(1)+2:length(header)-2); % don't copy the trailing '}\n'
header = [header_beg header];

% expand to the original size
% header = [header repmat(' ', 1, orig_size-length(header)-2) sprintf('}\n')]; % slower
header = [header sprintf('%*s}\n', orig_size-length(header)-2, ' ')]; % faster

% eof pmedf_removeInHeader.m
