%% wildcard2filelist_dir.m
%%
%% Makes a list of all files given by a wildcard, e.g. 'Si_*.edf' or
%% '*.txt'.
%% List is produced by the dir() command.
%% File names are returned in cell array files{}, i.e. files{1}, ...files{n}.
%%
%% Limitations in GNU Octave:
%%     - no, any shell wildcard can be used, e.g. 'Si_00[05].ed[fh]'.
%%     - output of this function is identical to command glob().
%%
%% Limitations in Matlab:
%%     - dir() command limitation: only '*' as a wildcard character can be used
%%     - use my another function wildcard2filelist() if you need shell wilcards
%%	 and run on unix-like system or have the "ls" command available
%%
%% Thus, if you run Matlab on Windows and "wildcards2filelist.m" does not work,
%% replace it by this function.
%%
%% Syntax:
%%	files = wildcard2filelist_dir( wild )
%%
%% Examples (the latter requires Octave or a unix shell):
%%	files = wildcard2filelist_dir( '*.edf' );
%%	files = wildcard2filelist_dir( 'Si_scan00[0-5].edf' )
%%
%% Author: Petr Mikulik
%% Version: January 2017

function files = wildcard2filelist_dir( wildcard )

if nargin~=1
    error('Syntax: files = wildcard2filelist_dir( wildcard )');
end

% Get the file list by the dir() command:
f = dir(wildcard);
files = cell(numel(f), 1);
for i = 1:numel(files)
    files{i} = f(i).name;
end

% eof wildcard2filelist_dir.m
